@@ -5,7 +5,7 @@ OC.L10N.register(
     "Due yesterday" : "Pour hier",
     "Due today" : "Pour aujourd'hui",
     "Due tomorrow" : "Pour demain",
-    "Due on" : "Echéance",
+    "Due on" : "Échéance",
     "Started yesterday" : "Débutées hier",
     "Starts today" : "Débute aujourd'hui",
     "Starts tomorrow" : "Débute demain",
@@ -49,7 +49,7 @@ OC.L10N.register(
     "This will delete the Calendar \"%s\" and all of its entries." : "Ceci va supprimer le Calendrier \"%s\" et tout son contenu.",
     "The name \"%s\" is already used." : "Le nom \"%s\" est déjà utilisé.",
     "An empty name is not allowed." : "Un nom vide n'est pas autorisé.",
-    "Hidden" : "Caché",
+    "Hidden" : "Masqué",
     "Visible" : "Visible",
     "Automatic" : "Automatique",
     "Sunday" : "Dimanche",
@@ -87,7 +87,7 @@ OC.L10N.register(
     "Completed" : "Terminé",
     "Delete" : "Supprimer",
     "Cancel" : "Annuler",
-    "Edit" : "Éditer",
+    "Edit" : "Modifier",
     "Link" : "Lien",
     "Download" : "Télécharger",
     "Save" : "Enregistrer",
@@ -96,7 +96,7 @@ OC.L10N.register(
     "Settings" : "Paramètres",
     "Start of week" : "Début de semaine",
     "Visibility of Smart Collections" : "Visibilité des collections Smart",
-    "Change sort order" : "Changer l'ordre de tri",
+    "Change sort order" : "Modifier l'ordre de tri",
     "Default" : "Défaut",
     "Due date" : "Date d'échéance",
     "Start date" : "Date de début",
@@ -106,7 +106,7 @@ OC.L10N.register(
     "Load remaining completed tasks." : "Charger le reste des tâches terminées.",
     "All day" : "Tous les jours",
     "(New category)" : "(Nouvelle catégorie)",
-    "Select categories..." : "Sélectionner des catégories...",
+    "Select categories..." : "Sélectionner des catégories…",
     "Loading the task..." : "Chargement de la tâche…",
     "Task not found!" : "Tâche non trouvée !",
     "add a subtask to" : "ajouter une sous-tâche à"
