@@ -96,8 +96,15 @@ OC.L10N.register(
     "Settings" : "Stillingar",
     "Start of week" : "Upphaf viku",
     "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
+    "Change sort order" : "Breyta röðun",
     "Default" : "Sjálfgefið",
+    "Due date" : "Skiladagur",
+    "Start date" : "Upphafsdagur",
+    "Priority" : "Forgangur",
+    "Alphabetically" : "Í stafrófsröð",
+    "Manually" : "Handvirkt",
     "Load remaining completed tasks." : "Hlaða inn afgangnum af loknum verkum.",
+    "All day" : "Heilsdagsviðburður",
     "(New category)" : "(nýr flokkur)",
     "Select categories..." : "Veldu flokka...",
     "Loading the task..." : "Hleð inn verkinu...",
