@@ -18,6 +18,7 @@ OC.L10N.register(
     "Yesterday" : "Vakar",
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
+    "in %s" : "%s",
     "%s ago" : "prieš %s",
     "seconds" : "sekundžių",
     "a minute" : "min.",
@@ -85,18 +86,25 @@ OC.L10N.register(
     "Current" : "Dabartinis",
     "Completed" : "Atliktas",
     "Delete" : "Ištrinti",
-    "Cancel" : "Atšaukti",
+    "Cancel" : "Atsisakyti",
     "Edit" : "Redaguoti",
     "Link" : "Nuoroda",
     "Download" : "Atsisiųsti",
-    "Save" : "Išsaugoti",
+    "Save" : "Įrašyti",
     "Add List..." : "Pridėti sąrašą...",
     "New List" : "Naujas sąrašas",
-    "Settings" : "Parinktys",
+    "Settings" : "Nustatymai",
     "Start of week" : "Savaitės pradžia",
     "Visibility of Smart Collections" : "Išmanių rinkinių matomumas",
+    "Change sort order" : "keisti rikiavimo tvarką",
     "Default" : "Numatytasis",
+    "Due date" : "Atlikimo terminas",
+    "Start date" : "Pradžios data",
+    "Priority" : "Prioritetas",
+    "Alphabetically" : "Pagal abėcėlę",
+    "Manually" : "Rankiniu būdu",
     "Load remaining completed tasks." : "Įkelti likusias atliktas užduotis.",
+    "All day" : "Visą dieną",
     "(New category)" : "(Nauja kategorija)",
     "Select categories..." : "Pasirinkite kategorijas...",
     "Loading the task..." : "Įkeliama užduotis...",
