@@ -63,16 +63,23 @@ OC.L10N.register(
     "Add an item due today in \"%s\"..." : "Pievienot \"%s\" ierakstu ar termiņu šodien ",
     "Add an item in \"%s\"..." : "Pievienot \"%s\" ierakstu",
     "Add a current item in \"%s\"..." : "Pievienot \"%s\" pašreizējo ierakstu",
+    "Add a subtask to \"%s\"..." : "Pievienot apakšuzdevumu \"%s\"...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["neviena pabeigta uzdevuma","%n paeigts uzdevums","%n pabeigti uzvedumi"],
     "Hours" : "Stundas",
     "Minutes" : "Minūtes",
     "Set due date" : "Uzstādīt izpildes termiņu",
     "%s %% completed" : "%s %% izpildīti",
+    "priority %s: " : "prioritāte %s:",
+    "high" : "augsta",
+    "medium" : "vidēja",
+    "low" : "zema",
+    "no priority assigned" : "nav piešķirta prioritāte",
     "Remind me" : "Atgādināt",
     "at the end" : "beigās",
     "at the beginning" : "sākumā",
     "Set start date" : "Uzstādīt sākuma datumu",
     "{calendar} shared by {owner}" : "{calendar} dalījās {owner}",
+    "Unnamed" : "Nenosaukts",
     "Important" : "Svarīgi",
     "Week" : "Nedēļa",
     "All" : "Visi",
@@ -89,9 +96,19 @@ OC.L10N.register(
     "Settings" : "Iestatījumi",
     "Start of week" : "Nedēļas sākums",
     "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
+    "Change sort order" : "Mainīt kārtošanas secību",
     "Default" : "Noklusējuma",
+    "Due date" : "Izpildes datums",
+    "Start date" : "Sākuma datums",
+    "Priority" : "Prioritāte",
+    "Alphabetically" : "Alfabētiskā secībā",
+    "Manually" : "Manuāli",
     "Load remaining completed tasks." : "Ielādēt pārējos pabeigtos uzdevumus.",
+    "All day" : "Visas dienas",
+    "(New category)" : "(Jauna kategorija)",
+    "Select categories..." : "Atlasiet kategoriju...",
     "Loading the task..." : "Ielādē uzdevumu...",
-    "Task not found!" : "Uzdevums nav atrasts!"
+    "Task not found!" : "Uzdevums nav atrasts!",
+    "add a subtask to" : "pievienot apakšuzdevumu"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
