@@ -85,7 +85,7 @@ OC.L10N.register(
     "All" : "Alla",
     "Current" : "Nuvarande",
     "Completed" : "Slutförande",
-    "Delete" : "Ta bort",
+    "Delete" : "Radera",
     "Cancel" : "Avbryt",
     "Edit" : "Ändra",
     "Link" : "Länk",
@@ -96,8 +96,15 @@ OC.L10N.register(
     "Settings" : "Inställningar",
     "Start of week" : "Början av vecka",
     "Visibility of Smart Collections" : "Synlighet av smarta samlingar",
+    "Change sort order" : "Ändra sorteringsordning",
     "Default" : "Förvald",
+    "Due date" : "Slutdatum",
+    "Start date" : "Startdatum",
+    "Priority" : "Prioritet",
+    "Alphabetically" : "Alfabetisk",
+    "Manually" : "Manuellt",
     "Load remaining completed tasks." : "Ladda återstående slutförda uppgifter.",
+    "All day" : "Hela dagen",
     "(New category)" : "(Ny kategori)",
     "Select categories..." : "Välj kategorier...",
     "Loading the task..." : "Laddar uppgiften",
