@@ -96,8 +96,15 @@ OC.L10N.register(
     "Settings" : "Ayarlar",
     "Start of week" : "Hafta başlangıcı",
     "Visibility of Smart Collections" : "Akıllı Koleksiyon Görünürlüğü",
+    "Change sort order" : "Sıralama düzenini değiştir",
     "Default" : "Öntanımlı",
+    "Due date" : "Bitiş tarihi",
+    "Start date" : "Başlangıç ​​tarihi",
+    "Priority" : "Öncelik",
+    "Alphabetically" : "Alfabetik",
+    "Manually" : "Manuel",
     "Load remaining completed tasks." : "Geri kalan tamamlanmış görevleri yükle.",
+    "All day" : "Tüm günlük",
     "(New category)" : "(Yeni kategori)",
     "Select categories..." : "Kategorileri seçin...",
     "Loading the task..." : "Görev yükleniyor...",
